% An example of noise overwhelming a deconvolved image
% Corresponds to Figure 1 in the write-up

true = phantom('Modified Shepp-Logan',512); % True image
PSF = reshape(textread('aperture.txt'),512,512); % PSF
blurry = ifft2(fft2(true) .* fft2(PSF)); % Blurred image

% Deconvolve it without noise in the PSF
clear_image = ifft2(fft2(blurry) ./ fft2(PSF));

% Add noise to the PSF
noisy = blurry + randn(length(blurry))*3*10^(-5);

% Deconvolve it with noise in the PSF
noisy_image = ifft2(fft2(noisy) ./ fft2(PSF));

figure;
g1=subplot(221);imagesc(true);title('True Image');
set(g1, 'XTickLabel', [], 'XTick', []);set(g1, 'YTickLabel', [], 'YTick', []); % Removes axes numbers & ticks
g2=subplot(222);imagesc(blurry);title('Blurred Image');
set(g2, 'XTickLabel', [], 'XTick', []);set(g2, 'YTickLabel', [], 'YTick', []);
g3=subplot(223);imagesc(clear_image);title('Deconvolved Image without Noise in the PSF');
set(g3, 'XTickLabel', [], 'XTick', []);set(g3, 'YTickLabel', [], 'YTick', []);
g4=subplot(224);imagesc(noisy_image);title('Deconvolved Image with Noise in the PSF');
set(g4, 'XTickLabel', [], 'XTick', []);set(g4, 'YTickLabel', [], 'YTick', []);
